/* $NetBSD: lsym_type_outside_parentheses.c,v 1.3 2022/04/24 09:04:12 rillig Exp $ */

/*
 * Tests for the token lsym_type_outside_parentheses, which represents a type
 * name outside parentheses, such as in a declaration that is not for a
 * function.
 */

//indent input
// TODO: add input
//indent end

//indent run-equals-input
