/* $NetBSD: opt_cd.c,v 1.4 2022/04/24 09:04:12 rillig Exp $ */

//indent input
int aflag; /* Apply to all files. */
//indent end

//indent run -cd49
int		aflag;				/* Apply to all files. */
//indent end

/* If '-cd' is not given, it falls back to '-c'. */
//indent run-equals-prev-output -c49
